Anyscale Command Line
===================

.. click:: any.scripts:project_create
   :prog: any project create
   :show-nested:

.. click:: any.scripts:project_list
   :prog: any project list
   :show-nested:

.. click:: any.scripts:project_validate
   :prog: any project validate
   :show-nested:

.. click:: any.scripts:snapshot_create
   :prog: any snapshot create
   :show-nested:

.. click:: any.scripts:snapshot_delete
    :prog: any snapshot delete
    :show-nested:

.. click:: any.scripts:snapshot_list
    :prog: any snapshot list
    :show-nested:

.. click:: any.scripts:session_start
   :prog: any session start
   :show-nested:

.. click:: any.scripts:session_execute
   :prog: any session execute
   :show-nested:

.. click:: any.scripts:session_stop
   :prog: any session stop
   :show-nested:

.. click:: any.scripts:session_list
   :prog: any session list
   :show-nested:
